summaryrefslogtreecommitdiff
path: root/condvar.c
diff options
context:
space:
mode:
authorrpj <rpj>2000-08-17 10:18:36 +0000
committerrpj <rpj>2000-08-17 10:18:36 +0000
commita366b6d8c2e6debf247c82af3d41aa2483711c52 (patch)
treee2a2f6785897a8789f88403e99d4f03dce301607 /condvar.c
parent951895c3aa196e90d4a5ecefe337d8773b8d33b7 (diff)
2000-08-17 Ross Johnson <rpj@special.ise.canberra.edu.au>
* All applicable: Change _pthread_ prefix to ptw32_ prefix to remove leading underscores from private library identifiers (single and double leading underscores are reserved in the ANSI C standard for compiler implementations).
Diffstat (limited to 'condvar.c')
-rw-r--r--condvar.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/condvar.c b/condvar.c
index 98f1f23..0f74c9f 100644
--- a/condvar.c
+++ b/condvar.c
@@ -52,7 +52,7 @@ _cond_check_need_init(pthread_cond_t *cond)
* the number of processors + 1.
*
*/
- EnterCriticalSection(&_pthread_cond_test_init_lock);
+ EnterCriticalSection(&ptw32_cond_test_init_lock);
/*
* We got here possibly under race
@@ -75,7 +75,7 @@ _cond_check_need_init(pthread_cond_t *cond)
result = EINVAL;
}
- LeaveCriticalSection(&_pthread_cond_test_init_lock);
+ LeaveCriticalSection(&ptw32_cond_test_init_lock);
return(result);
}
@@ -492,7 +492,7 @@ pthread_cond_destroy (pthread_cond_t * cond)
/*
* See notes in _cond_check_need_init() above also.
*/
- EnterCriticalSection(&_pthread_cond_test_init_lock);
+ EnterCriticalSection(&ptw32_ond_test_init_lock);
/*
* Check again.
@@ -516,7 +516,7 @@ pthread_cond_destroy (pthread_cond_t * cond)
result = EBUSY;
}
- LeaveCriticalSection(&_pthread_cond_test_init_lock);
+ LeaveCriticalSection(&ptw32_cond_test_init_lock);
}
return (result);
@@ -655,14 +655,14 @@ cond_timedwait (pthread_cond_t * cond,
* timeout
*
* Note:
* _pthread_sem_timedwait is a cancelation point,
* hence providing the
* mechanism for making pthread_cond_wait a cancelation
* point. We use the cleanup mechanism to ensure we
* re-lock the mutex and decrement the waiters count
* if we are canceled.
*/
- if (_pthread_sem_timedwait (&(cv->sema), abstime) == -1)
+ if (ptw32_sem_timedwait (&(cv->sema), abstime) == -1)
{
result = errno;
}
@@ -947,7 +947,7 @@ pthread_cond_broadcast (pthread_cond_t * cond)
#ifdef NEED_SEM
- result = (_pthread_increase_semaphore( &cv->sema, cv->waiters )
+ result = (ptw32_increase_semaphore( &cv->sema, cv->waiters )
? 0
: EINVAL);
@@ -655,14 +655,14 @@ cond_timedwait (pthread_cond_t * cond,
*
* Note:
- * _pthread_sem_timedwait is a cancelation point,
+ * ptw32_sem_timedwait is a cancelation point,
* hence providing the
* mechanism for making pthread_cond_wait a cancelation